@@ -24,7 +24,6 @@ class GuidUrlSafe:
 
 
 
-
 class ExtendedJsonEncoder(json.JSONEncoder):
 
     def __init__(self,  *args, **kwargs):
@@ -36,6 +35,7 @@ class ExtendedJsonEncoder(json.JSONEncoder):
         # Consider: This seems like a ton of work for a constructor
         #
         self.pandas_dynamic = None
+
         try:
             logger.info("Searching for pandas module dynamically")
             self.pandas_dynamic = importlib.import_module('pandas')
@@ -45,6 +45,17 @@ class ExtendedJsonEncoder(json.JSONEncoder):
             logger.info("Did not find pandas")
             pass
 
+        self.np_dynamic = None
+        try:
+            logger.info("Searching for numpy module dynamically")
+            self.np_dynamic = importlib.import_module('numpy')
+            logger.info("Found numpy module dynamically")
+        except ImportError as err:
+            # pandas not found, leave as null so it can be skipped below
+            logger.info("Did not find numpy")
+            pass
+
+
     def default(self, o):
         if isinstance(o, decimal.Decimal):
             if abs(o % 1) > 0:  # without abs() negative float values were being converted to int
@@ -57,6 +68,19 @@ class ExtendedJsonEncoder(json.JSONEncoder):
             posix_float_timestamp = o.timestamp()
             timestamp_as_millis = int(1000.0 * posix_float_timestamp)
             return int(timestamp_as_millis)
+        elif (self.np_dynamic is not None):
+
+            np =self.np_dynamic
+            if isinstance(o, (np.int_, np.intc, np.intp, np.int8,
+                              np.int16, np.int32, np.int64, np.uint8,
+                              np.uint16, np.uint32, np.uint64)):
+                return int(o)
+            elif isinstance(o, (np.float_, np.float16, np.float32,
+                                np.float64)):
+                return float(o)
+            elif isinstance(o, (np.ndarray,)):  #### This is the fix
+                return o.tolist()
+
         elif isinstance(o, datetime.date):
             return o.isoformat()
 
